Generates a classic layered architecture test file.
mix arch_test.gen.layers
Creates test/arch/layers_arch_test.exs enforcing that web may only depend on context, and context may only depend on repo — never upward.
test/arch/layers_arch_test.exs